You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by rj...@apache.org on 2011/07/10 19:12:20 UTC

svn commit: r1144906 - in /tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni: Address.java BIOCallback.java Directory.java File.java Local.java OS.java Poll.java Pool.java Proc.java Shm.java Socket.java Time.java User.java

Author: rjung
Date: Sun Jul 10 17:12:19 2011
New Revision: 1144906

URL: http://svn.apache.org/viewvc?rev=1144906&view=rev
Log:
Sync tcnative 1.1.x Java classes with TC 7:
- only JavaDoc, no functional change.

Modified:
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Address.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/BIOCallback.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Directory.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/File.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Local.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/OS.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Poll.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Pool.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Proc.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Shm.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Socket.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Time.java
    tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/User.java

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Address.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Address.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Address.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Address.java Sun Jul 10 17:12:19 2011
@@ -25,7 +25,7 @@ package org.apache.tomcat.jni;
 
 public class Address {
 
-    static public final String APR_ANYADDR = "0.0.0.0";
+    public static final String APR_ANYADDR = "0.0.0.0";
     /**
      * Fill the Sockaddr class from apr_sockaddr_t
      * @param info Sockaddr class to fill

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/BIOCallback.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/BIOCallback.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/BIOCallback.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/BIOCallback.java Sun Jul 10 17:12:19 2011
@@ -27,7 +27,7 @@ public interface BIOCallback {
 
     /**
      * Write data
-     * @param buf containg the bytes to write.
+     * @param buf containing the bytes to write.
      * @return Number of characters written.
      */
     public int write(byte [] buf);
@@ -49,7 +49,7 @@ public interface BIOCallback {
     /**
      * Read string up to the len or CLRLF
      * @param len Maximum number of characters to read
-     * @return String with up to len bytes readed
+     * @return String with up to len bytes read
      */
     public String gets(int len);
 

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Directory.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Directory.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Directory.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Directory.java Sun Jul 10 17:12:19 2011
@@ -28,7 +28,7 @@ public class Directory {
     /**
      * Create a new directory on the file system.
      * @param path the path for the directory to be created. (use / on all systems)
-     * @param perm Permissions for the new direcoty.
+     * @param perm Permissions for the new directory.
      * @param pool the pool to use.
      */
     public static native int make(String path, int perm, long pool);
@@ -37,7 +37,7 @@ public class Directory {
      * 'mkdir -p'. Creates intermediate directories as required. No error
      * will be reported if PATH already exists.
      * @param path the path for the directory to be created. (use / on all systems)
-     * @param perm Permissions for the new direcoty.
+     * @param perm Permissions for the new directory.
      * @param pool the pool to use.
      */
     public static native int makeRecursive(String path, int perm, long pool);

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/File.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/File.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/File.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/File.java Sun Jul 10 17:12:19 2011
@@ -419,7 +419,7 @@ public class File {
     public static native int writeFullb(long thefile, ByteBuffer buf, int offset, int nbytes);
 
     /**
-     * Write data from aray of byte arrays to the specified file.
+     * Write data from array of byte arrays to the specified file.
      *
      * It is possible for both bytes to be written and an error to
      * be returned.  APR_EINTR is never returned.
@@ -433,7 +433,7 @@ public class File {
     public static native int writev(long thefile, byte[][] vec);
 
     /**
-     * Write data from aray of byte arrays to the specified file,
+     * Write data from array of byte arrays to the specified file,
      * ensuring that all of the data is written before returning.
      *
      * writevFull is available even if the underlying
@@ -543,7 +543,7 @@ public class File {
     /**
      * Read a character from the specified file.
      * @param thefile The file descriptor to read from
-     * @return The readed character
+     * @return The read character
      */
     public static native int getc(long thefile)
         throws Error;
@@ -576,7 +576,7 @@ public class File {
 
     /**
      * Set attributes of the specified file.
-     * This function should be used in preference to explict manipulation
+     * This function should be used in preference to explicit manipulation
      *      of the file permissions, because the operations to provide these
      *      attributes are platform specific and may involve more than simply
      *      setting permission bits.
@@ -624,7 +624,7 @@ public class File {
     /**
      * Retrieve the flags that were passed into apr_file_open()
      * when the file was opened.
-     * @param file The file to retrive flags.
+     * @param file The file to retrieve flags.
      * @return the flags
      */
     public static native int flagsGet(long file);

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Local.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Local.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Local.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Local.java Sun Jul 10 17:12:19 2011
@@ -48,7 +48,7 @@ public class Local {
      * @param sock The socket to listen on
      * @param backlog The number of outstanding connections allowed in the sockets
      *                listen queue.  If this value is less than zero, for NT pipes
-     *                the number of instances is unlimite.
+     *                the number of instances is unlimited.
      *
      */
     public static native int listen(long sock, int backlog);

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/OS.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/OS.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/OS.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/OS.java Sun Jul 10 17:12:19 2011
@@ -58,7 +58,7 @@ public class OS {
     public static final boolean IS_MACOSX  = is(MACOSX);
 
     /**
-     * Get the name of the system default characer set.
+     * Get the name of the system default character set.
      * @param pool the pool to allocate the name from, if needed
      */
     public static native String defaultEncoding(long pool);
@@ -66,7 +66,7 @@ public class OS {
     /**
      * Get the name of the current locale character set.
      * Defers to apr_os_default_encoding if the current locale's
-     * data can't be retreved on this system.
+     * data can't be retrieved on this system.
      * @param pool the pool to allocate the name from, if needed
      */
     public static native String localeEncoding(long pool);

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Poll.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Poll.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Pool.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Pool.java Sun Jul 10 17:12:19 2011
@@ -142,8 +142,8 @@ public class Pool {
      * <br /><b>Warning :</b>
      * The data to be attached to the pool should have a life span
      * at least as long as the pool it is being attached to.
-     * Object attached to the pool will be globaly referenced
-     * untill the pool is cleared or dataSet is called with the null data.
+     * Object attached to the pool will be globally referenced
+     * until the pool is cleared or dataSet is called with the null data.
      * @return APR Status code.
      */
      public static native int dataSet(long pool, String key, Object data);

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Proc.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Proc.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Proc.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Proc.java Sun Jul 10 17:12:19 2011
@@ -65,7 +65,7 @@ public class Proc {
     public static final int APR_OC_REASON_DEATH      = 0;
     /** write_fd is unwritable */
     public static final int APR_OC_REASON_UNWRITABLE = 1;
-    /** a restart is occuring, perform any necessary cleanup (including
+    /** a restart is occurring, perform any necessary cleanup (including
      * sending a special signal to child)
      */
     public static final int APR_OC_REASON_RESTART    = 2;
@@ -75,7 +75,7 @@ public class Proc {
     public static final int APR_OC_REASON_UNREGISTER = 3;
     /** somehow the child exited without us knowing ... buggy os? */
     public static final int APR_OC_REASON_LOST       = 4;
-    /** a health check is occuring, for most maintainence functions
+    /** a health check is occurring, for most maintenance functions
      * this is a no-op.
      */
     public static final int APR_OC_REASON_RUNNING    = 5;
@@ -101,7 +101,7 @@ public class Proc {
     public static final int MAX_ENV_SIZE           = 1024;
 
     /**
-     * Allocate apr_proc_t stucture from pool
+     * Allocate apr_proc_t structure from pool
      * This is not an apr function.
      * @param cont The pool to use.
      */

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Shm.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Shm.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Shm.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Shm.java Sun Jul 10 17:12:19 2011
@@ -28,11 +28,11 @@ import java.nio.ByteBuffer;
 public class Shm {
 
     /**
-     * Create and make accessable a shared memory segment.
+     * Create and make accessible a shared memory segment.
      * <br />
      * A note about Anonymous vs. Named shared memory segments:<br />
-     *         Not all plaforms support anonymous shared memory segments, but in
-     *         some cases it is prefered over other types of shared memory
+     *         Not all platforms support anonymous shared memory segments, but in
+     *         some cases it is preferred over other types of shared memory
      *         implementations. Passing a NULL 'file' parameter to this function
      *         will cause the subsystem to use anonymous shared memory segments.
      *         If such a system is not available, APR_ENOTIMPL is returned.

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Socket.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Socket.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Socket.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Socket.java Sun Jul 10 17:12:19 2011
@@ -483,7 +483,7 @@ public class Socket {
      * @param t Value for the timeout in microseconds.
      * <PRE>
      * t > 0  -- read and write calls return APR_TIMEUP if specified time
-     *           elapsess with no data read or written
+     *           elapses with no data read or written
      * t == 0 -- read and write calls never block
      * t < 0  -- read and write calls block
      * </PRE>
@@ -537,8 +537,8 @@ public class Socket {
         throws Exception;
 
     /**
-     * Private method for geting the socket struct members
-     * @param socket The soocket to use
+     * Private method for getting the socket struct members
+     * @param socket The socket to use
      * @param what Struct member to obtain
      * <PRE>
      * SOCKET_GET_POOL  - The socket pool
@@ -546,7 +546,7 @@ public class Socket {
      * SOCKET_GET_APRS  - APR socket
      * SOCKET_GET_TYPE  - Socket type
      * </PRE>
-     * @return The stucture member address
+     * @return The structure member address
      */
     private static native long get(long socket, int what);
 

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Time.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Time.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Time.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Time.java Sun Jul 10 17:12:19 2011
@@ -27,7 +27,7 @@ public class Time {
 
     /** number of microseconds per second */
     public static final long APR_USEC_PER_SEC  = 1000000L;
-    /** number of miliseconds per microsecond */
+    /** number of milliseconds per microsecond */
     public static final long APR_MSEC_PER_USEC = 1000L;
 
     /** @return apr_time_t as a second */
@@ -43,7 +43,7 @@ public class Time {
     }
 
     /**
-     * number of microseconds since 00:00:00 january 1, 1970 UTC
+     * number of microseconds since 00:00:00 January 1, 1970 UTC
      * @return the current time
      */
     public static native long now();

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/User.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/User.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/User.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/User.java Sun Jul 10 17:12:19 2011
@@ -99,7 +99,7 @@ public class User {
      * This function is available only if APR_HAS_USER is defined.
      * @param left One uid to test
      * @param right Another uid to test
-     * @return APR_SUCCESS if the apr_uid_t strutures identify the same user,
+     * @return APR_SUCCESS if the apr_uid_t structures identify the same user,
      * APR_EMISMATCH if not, APR_BADARG if an apr_uid_t is invalid.
      */
      public static native int uidcompare(long left, long right);
@@ -109,7 +109,7 @@ public class User {
      * This function is available only if APR_HAS_USER is defined.
      * @param left One gid to test
      * @param right Another gid to test
-     * @return APR_SUCCESS if the apr_gid_t strutures identify the same group,
+     * @return APR_SUCCESS if the apr_gid_t structures identify the same group,
      * APR_EMISMATCH if not, APR_BADARG if an apr_gid_t is invalid.
      */
      public static native int gidcompare(long left, long right);



---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@tomcat.apache.org
For additional commands, e-mail: dev-help@tomcat.apache.org
--- tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Poll.java (original)
+++ tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Poll.java Sun Jul 10 17:12:19 2011
@@ -33,7 +33,7 @@ public class Poll {
     public static final int APR_POLLOUT  = 0x004; /** Can write without blocking */
     public static final int APR_POLLERR  = 0x010; /** Pending error */
     public static final int APR_POLLHUP  = 0x020; /** Hangup occurred */
-    public static final int APR_POLLNVAL = 0x040; /** Descriptior invalid */
+    public static final int APR_POLLNVAL = 0x040; /** Descriptor invalid */
 
     /**
      * Pollset Flags
@@ -76,7 +76,7 @@ public class Poll {
      * Add a socket or to a pollset
      * If you set client_data in the descriptor, that value
      * will be returned in the client_data field whenever this
-     * descriptor is signalled in apr_pollset_poll().
+     * descriptor is signaled in apr_pollset_poll().
      * @param pollset The pollset to which to add the descriptor
      * @param sock The sockets to add
      * @param reqevents requested events
@@ -95,15 +95,15 @@ public class Poll {
      * Block for activity on the descriptor(s) in a pollset
      * @param pollset The pollset to use
      * @param timeout Timeout in microseconds
      * @param descriptors Array of signalled descriptors (output parameter)
      *        The desctiptor array must be two times the size of pollset.
      *        and are populated as follows:
      * <PRE>
-     * descriptors[n + 0] -> returned events
-     * descriptors[n + 1] -> socket
+     * descriptors[2n + 0] -> returned events
+     * descriptors[2n + 1] -> socket
      * </PRE>
      * @param remove Remove signaled descriptors from pollset
-     * @return Number of signalled descriptors (output parameter)
+     * @return Number of signaled descriptors (output parameter)
      *         or negative APR error code.
      */
     public static native int poll(long pollset, long timeout,
@@ -112,14 +112,14 @@ public class Poll {
     /**
      * Maintain on the descriptor(s) in a pollset
      * @param pollset The pollset to use
      * @param descriptors Array of signalled descriptors (output parameter)
      *        The desctiptor array must be the size of pollset.
      *        and are populated as follows:
      * <PRE>
      * descriptors[n] -> socket
      * </PRE>
      * @param remove Remove signaled descriptors from pollset
-     * @return Number of signalled descriptors (output parameter)
+     * @return Number of signaled descriptors (output parameter)
      *         or negative APR error code.
      */
     public static native int maintain(long pollset, long [] descriptors,
@@ -143,11 +143,11 @@ public class Poll {
      * Return all descriptor(s) in a pollset
      * @param pollset The pollset to use
      * @param descriptors Array of descriptors (output parameter)
      *        The desctiptor array must be two times the size of pollset.
      *        and are populated as follows:
      * <PRE>
-     * descriptors[n + 0] -> returned events
-     * descriptors[n + 1] -> socket
+     * descriptors[2n + 0] -> returned events
+     * descriptors[2n + 1] -> socket
      * </PRE>
      * @return Number of descriptors (output parameter) in the Poll
      *         or negative APR error code.
@@ -95,15 +95,15 @@ public class Poll {
      * @param pollset The pollset to use
      * @param timeout Timeout in microseconds
-     * @param descriptors Array of signalled descriptors (output parameter)
-     *        The desctiptor array must be two times the size of pollset.
+     * @param descriptors Array of signaled descriptors (output parameter)
+     *        The descriptor array must be two times the size of pollset.
      *        and are populated as follows:
      * <PRE>
@@ -112,14 +112,14 @@ public class Poll {
      * Maintain on the descriptor(s) in a pollset
      * @param pollset The pollset to use
-     * @param descriptors Array of signalled descriptors (output parameter)
-     *        The desctiptor array must be the size of pollset.
+     * @param descriptors Array of signaled descriptors (output parameter)
+     *        The descriptor array must be the size of pollset.
      *        and are populated as follows:
      * <PRE>
@@ -143,11 +143,11 @@ public class Poll {
      * @param pollset The pollset to use
      * @param descriptors Array of descriptors (output parameter)
-     *        The desctiptor array must be two times the size of pollset.
+     *        The descriptor array must be two times the size of pollset.
      *        and are populated as follows:
      * <PRE>

Modified: tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Pool.java
URL: http://svn.apache.org/viewvc/tomcat/native/branches/1.1.x/java/org/apache/tomcat/jni/Pool.java?rev=1144906&r1=1144905&r2=1144906&view=diff
==============================================================================